# -*-coding:utf-8 -*- #
# ---------------------------------------------------------------------------
# ProjectName:   study_python
# FileName:      db.py
# Author:       xxxxxxx
# Datetime:     2024/9/7 10:42
# Description:
# 命名规范：文件名全小写+下划线，类名大驼峰，方法和变量小写+下划线连接，
# 常量大写，变量和常量用名词，方法用动词
# ---------------------------------------------------------------------------
import pymysql

from ApiAutoTese_3 import log
from ApiAutoTese_3.common.read_project_ini import Read_Project_Ini


class DB:
    def __init__(self):
        ini = Read_Project_Ini()
        self.db = pymysql.connect(
            host=ini.get_sql_conf('host'),
            port=int(ini.get_sql_conf('port')),
            user=ini.get_sql_conf('user'),
            password=ini.get_sql_conf('password'),
            database=ini.get_sql_conf('database'),
            charset='utf8'
        )
        self.cursor = self.db.cursor()

    def delete(self,sql):
        if isinstance(sql,str):
            if sql.lower().startswith('delete'):
                try:
                    self.cursor.execute(sql)
                    self.db.commit()
                except Exception as e:
                    log.error(f'执行sql语句错误，sql语句为{sql}，错误为{e}')
                    raise e
            else:
                log.error(f'执行delete方法sql语句不是delete语句,sql语句为{sql}')
                raise ValueError(f'执行delete方法sql语句不是delete语句')
        else:
            log.error(f'传入的sql语句类型不是字符串，sql为{sql}')
            raise TypeError(f'传入的sql语句类型不是字符串，sql为{sql}')

    def select(self,sql,n=0):
        if isinstance(sql,str):
            if sql.lower().startswith('select'):
                try:
                    self.cursor.execute(sql)
                except Exception as e:
                    log.error(f'执行sql语句错误，sql语句为{sql}，错误为{e}')
                    raise e
                else:
                    data = self.cursor.fetchall()
                if isinstance(n,int) and data:
                    try:
                        return data[n][0]
                    except Exception as e:
                        log.error(f"执行select方法时，获取查询结果失败，传入的n为：{n}")
                        raise e
            else:
                log.error(f'执行delete方法sql语句不是delete语句,sql语句为{sql}')
                raise ValueError(f'执行delete方法sql语句不是delete语句')
        else:
            log.error(f'传入的sql语句类型不是字符串，sql为{sql}')
            raise TypeError(f'传入的sql语句类型不是字符串，sql为{sql}')

    def close(self):
        self.cursor.close()
        self.db.close()